@@ -23,7 +23,7 @@ use Apache::TestConfig ();
 
 use vars qw(@ISA @EXPORT %EXPORT_TAGS $VERSION %SubTests @SkipReasons);
 
-$VERSION = '1.25';
+$VERSION = '1.26';
 
 my @need = qw(need_lwp need_http11 need_cgi need_access need_auth
               need_module need_apache need_min_apache_version
@@ -132,17 +132,19 @@ EOE
 #so Perl's Test.pm can be run inside mod_perl
 sub test_pm_refresh {
     if (@testmore) {
-        Test::Builder->reset;
+        my $builder = Test::Builder->new;
 
-        Test::Builder->output(\*STDOUT);
-        Test::Builder->todo_output(\*STDOUT);
+        $builder->reset;
+
+        $builder->output(\*STDOUT);
+        $builder->todo_output(\*STDOUT);
 
         # this is STDOUT because Test::More seems to put 
         # most of the stuff we want on STDERR, so it ends
         # up in the error_log instead of where the user can
         # see it.   consider leaving it alone based on
         # later user reports.
-        Test::Builder->failure_output(\*STDOUT);
+        $builder->failure_output(\*STDOUT);
     }
     else {
         $Test::TESTOUT = \*STDOUT;
@@ -459,10 +461,13 @@ sub need_threads {
 
     # check APR support
     my $build_config = Apache::TestConfig->modperl_build_config;
-    my $apr_config = $build_config->get_apr_config();
-    unless ($apr_config->{HAS_THREADS}) {
-        $status = 0;
-        push @SkipReasons, "Apache/APR was built without threads support";
+
+    if ($build_config) {
+        my $apr_config = $build_config->get_apr_config();
+        unless ($apr_config->{HAS_THREADS}) {
+            $status = 0;
+            push @SkipReasons, "Apache/APR was built without threads support";
+        }
     }
 
     # check Perl's useithreads
