@@ -49,8 +49,13 @@ sub configure_modperl {
     my $ver = $test_config->server->{version};
 
     # sanity checking and loading the right mod_perl version
+
+    # remove mod_perl.pm from %INC so that the below require()
+    # calls accurately populate $mp_ver
+    delete $INC{'mod_perl.pm'};
+
     if ($rev == 2) {
-        eval { require Apache2 && require mod_perl };
+        eval { require mod_perl2 };
     } else {
         eval { require mod_perl };
     }
